@@ -16,7 +16,7 @@ require	Exporter;
 use vars qw($VERSION @EXPORT @ISA %intervals);
 @ISA 		= qw(Exporter);
 @EXPORT		= qw(&parseInterval &convertInterval &getInterval &coalesce);
-$VERSION	= '1.0.4';
+$VERSION	= '1.0.5';
 #what everything is worth in seconds
 %intervals 	= (
 	'days'		=> ((60**2) * 24),
@@ -185,16 +185,17 @@ sub coalesce {
 	}
 	
 	#replace the epoch's with their time string equivalents
-	my $i = 0;
-	foreach (@{$intervals}){
-		if (ref ($_) eq "ARRAY"){
-			$_->[0] = $epoch_map{$_->[0]};
-			$_->[1] = $epoch_map{$_->[1]};
-		}else{
-			splice (@{$intervals}, $i, 1);
+	foreach my $pair (@{$intervals}){
+		if ( ref($pair) eq "ARRAY"){
+			foreach (@{$pair}){ $_ = $epoch_map{$_}; }
 		}
-		$i ++;
 	}
 	
+	#weed out any remaining bum elements
+	my $i = 0;
+	foreach (@{$intervals}){
+		unless (ref($_) eq "ARRAY"){ splice (@{$intervals}, $i, 1); }
+		$i ++;
+	}
 	return ($intervals);
 }
