@@ -57,11 +57,18 @@ foreach ('days','hours','minutes','seconds'){
 #test coalesce
 print "testing coalesce on: \n";
 my @date_ranges  = (
-	[ "5/13/04 10:00:00 EDT", "5/13/04 11:00:00 EDT" ],
-	[ "5/13/04 13:00:00 EDT", "5/13/04 14:00:00 EDT" ],
-	[ "5/13/04 10:50:00 EDT", "5/13/04 12:00:00 EDT" ],
-	[ "5/10/04 10:50:00 EDT", "5/11/04 12:00:00 EDT" ],
-	[ "5/13/04 9:50:00 EDT",  "5/13/04 11:00:00 EDT" ]
+#	[ "5/13/04 10:00:00 EDT", "5/13/04 11:00:00 EDT" ],
+#	[ "5/13/04 13:00:00 EDT", "5/13/04 14:00:00 EDT" ],
+#	[ "5/13/04 10:50:00 EDT", "5/13/04 12:00:00 EDT" ],
+#	[ "5/10/04 10:50:00 EDT", "5/11/04 12:00:00 EDT" ],
+#	[ "5/13/04 9:50:00 EDT",  "5/13/04 11:00:00 EDT" ],
+	[ "20040429 11:34:16", "20040430 02:19:30" ],
+	[ "20040429 11:34:16", "20040501 02:19:31" ],
+	[ "20040429 11:34:16", "20040502 02:19:31" ],
+	[ "20040429 11:34:16", "20040503 02:19:31" ],
+	[ "20040429 11:34:16", "20040504 02:19:31" ],
+	[ "20040429 11:34:16", "20040504 14:04:58" ]
+
 );
 foreach (@date_ranges){ print $_->[0], " - ", $_->[1], "\n"; }
 
